summaryrefslogtreecommitdiff
path: root/c/lib_obj.c
diff options
context:
space:
mode:
authorArmin Rigo <arigo@tunes.org>2015-11-18 10:00:42 +0100
committerArmin Rigo <arigo@tunes.org>2015-11-18 10:00:42 +0100
commit1b266852f4dc07efdca37f2fe495cc42b60c1a31 (patch)
treeacdbc0c3dd4fa858d0feb32ea4aabeb391b65f8d /c/lib_obj.c
parentb1cf6818bdbfe16776a811bcad318f5f8608ed8f (diff)
downloadcffi-1b266852f4dc07efdca37f2fe495cc42b60c1a31.tar.gz
update the code to use 'extern "Python"'
Diffstat (limited to 'c/lib_obj.c')
-rw-r--r--c/lib_obj.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/c/lib_obj.c b/c/lib_obj.c
index 6494825..f257800 100644
--- a/c/lib_obj.c
+++ b/c/lib_obj.c
@@ -364,8 +364,8 @@ static PyObject *lib_build_and_cache_attr(LibObject *lib, PyObject *name,
break;
}
- case _CFFI_OP_CALL_PYTHON:
- /* for reading 'lib.bar' where bar is declared with CFFI_CALL_PYTHON */
+ case _CFFI_OP_EXTERN_PYTHON:
+ /* for reading 'lib.bar' where bar is declared with extern "Python" */
ct = realize_c_type(types_builder, types_builder->ctx.types,
_CFFI_GETARG(g->type_op));
if (ct == NULL)